# NeSy Circuits

This folder contains SDDs for various NeSy experiments.
- 4-grid, taken from https://github.com/KareemYousrii/SPL.
- Road-R, taken from https://github.com/EGiunchiglia/ROAD-R.
- Warcraft_12, taken from https://github.com/KareemYousrii/SPL.
- Visual Sudoku.